Crate dkdc_sh

Crate dkdc_sh 

Shell utilities for tmux, git, and command management.

Minimal, synchronous shell abstractions. No async runtime required.

Modules

editor
Open files in the user’s preferred editor.
git
Git command abstractions (sync).
tmux
Tmux session management.

Enums

Error
Shell operation errors.

Functions

require
Require a command to exist, returning an error if not found.
run
Run a command and return its stdout.
run_with_env
Run a command with extra environment variables and return its stdout.
which
Check if a command exists in PATH.